Skip to content

build initramfs: speedup

John Reiser initramfs 1 version In review

Get series with b4
b4 am [email protected]

Versions newest first

  1. v1 Latest8 patches 4 repliesIn review

Patches in v1 No applies recorded yet

#Subject and filesSizeRepliesApplied
1/8inst_simple, inst_dir: make fast case fasterdracut-functions+5 -110 replies
2/8filter_kernel_modules is a specialized filter_kernel_modules_by_pathdracut-functions+3 -280 replies
3/8install_kmod_with_fw: make fast case fasterdracut-functions+3 -20 replies
4/8instmods: get filenames from stdin if no args; use itdracut-functions modules.d/40network/module-setup.sh modules.d/90kernel-modules/module-setup.sh +2 more+83 -300 replies
5/8instmods: sanity for _mpargsdracut-functions+7 -40 replies
6/8instmods: factor out egrep of "FATAL: Module .* not found"dracut-functions+19 -150 replies
7/8build initramfs: cpio avoids per-file /bin/cpdracut dracut-functions+21 -40 replies
8/8Close original fd after bash-generated high redirection.dracut dracut-functions+3 -20 replies

Reviews trailers per patch

No Reviewed-by, Acked-by or Tested-by trailers for v1 yet.

Read the v1 thread

Cover letter [PATCH 0/8] build initramfs: speedup

This patch series saves 50% (a factor of 2) in real time before final gzip when building initramfs for Fedora 16.

Probably you should apply only the first six patches (1,2,3,4,5,6) because directory symlinks and permissions aren't right after patch 7. [I don't care about directory symlinks now; permissions are 775 instead of 755.] I'm working on a different approach for those; it's not ready. However, the first six patches save 25% (a factor of 4/3),
and patch 7 saves another 25% by replacing most /bin/cp with cpio.